toml: Python Library for Tom's Obvious, Minimal Language
========================================================

Description
-----------

Python Library for Tom's Obvious, Minimal Language

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/toml/

